@@ -40,8 +40,8 @@ tam_mml_create_nodes <- function(snodes, nodes, ndim, QMC,
 				theta0.samp <- theta0.samp[ order(theta0.samp[,1]) , ]
 			}
 		} else {
-			theta0.samp <- matrix( MASS::mvrnorm( snodes , mu = rep(0,ndim) , 
-                                        Sigma = diag(1,ndim ) )	, nrow= snodes , ncol=ndim )			
+			theta0.samp <- matrix( CDM::CDM_rmvnorm( snodes , mean = rep(0,ndim) , 
+                                        sigma = diag(1,ndim ) )	, nrow= snodes , ncol=ndim )			
 		}
 		nnodes <- nrow(theta0.samp)
     }
