@@ -6,7 +6,7 @@ tam_pv_mcmc_proposal_theta <- function(theta, nstud, variance, adj_MH, D, G, gro
 	for (gg in 1:G){
 		ind_gg <- group_index[[gg]]
 		nstud_gg <- attr( group_index , "N_groups")[gg]	
-		samp_values <- matrix( mvtnorm::rmvnorm( nstud_gg , sigma=variance[[gg]] ) , ncol=D )
+		samp_values <- matrix( CDM::CDM_rmvnorm( nstud_gg , sigma=variance[[gg]] ) , ncol=D )
 		theta_new[ind_gg,] <- theta[ind_gg,] + adj_MH[ind_gg] * samp_values
 	}
 	return(theta_new)
